#! /usr/bin/python
# -*- coding: utf-8 -*-

# HARK Middleware
# Copyright (C) 2013-2019 by Honda Research Institute Japan Co., Ltd.
# $Id:$

from harkmw.HarkError import HARKError

def xml_node_path(node):
    """XML ノードから xpath 名を返す。

    Parameters
    ----------
    node : Node
        処理の対象となるノード
    """
    parent = node.parentNode
    if parent is None:
        return "/%s" % node.name

    else:
        return "%s/%s" % (xml_node_path(parent), node.name)


def xml_attribute(node, name, required=True, default=None):
    """XML ノードから指定した属性値を返す。

    Parameters
    ----------
    node : Node
        処理の対象となるノード
    name : str
        取得する属性の名前
    required : bool
        指定した属性が存在しない場合に例外を raise する場合には True を指定する
    default : object
        指定した属性が存在しない場合に用いる既定値
    """
    if node.getAttributeNode(name):
        return node.attributes[name].value

    elif required:
        raise HARKError("Element %s does not have attribute with name '%s'" % (
            xml_node_path(node), name))

    else:
        return default

# end of file
