/* -*- mode: C++; coding: utf-8 -*- */

/*
 * Copyright (c) 2013 - 2020 Honda Research Institute Japan Co., Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 * 
 * Licensed under the HARK license, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * https://www.hark.jp/notice/HARK_License_Agreement.pdf
 */

#if !defined(HARKMW__NODE_H__INCLUDED)
#define HARKMW__NODE_H__INCLUDED 1

/* Python API */
//#include <structmember.h>

/* HARK Base */
#include <hark-base/Node.h>

namespace HARKMW
{
extern PyTypeObject NodeType;

class Node {
public:
    py::object nodeObject;
    HARK::Node *node;

private:
    Node() = delete;
    Node(const Node &) = delete;
    Node &operator = (const Node &) = delete;
    Node(const Node &&) = delete;
    Node &operator = (const Node &&) = delete;

public:
    Node(py::object node, const std::string &name, py::object parameters);
    virtual ~Node();

    size_t get_input_count() const;
    size_t get_output_count() const;
    py::object get_output(const std::string &name, int count);
    void connect(const std::string &in, Node *inputNode, const std::string &out);
    std::pair<int, int> get_output_look_window(const std::string &output_id) const;
    std::pair<int, int> get_input_look_window(const std::string &output_id) const;
    void set_output_look_window(const std::string &output_id, int lookAhead, int lookBack);
    void set_input_look_window(const std::string &output_id, int lookAhead, int lookBack);
    void initialize();
    void process(const std::string &output_name, int count, int input_count = -1, int output_count = -1);
    void dump_input(int count) const;
};

}

#endif /* #if !defined(HARKMW__NODE_H__INCLUDED) */

/* end of file */
